@@ -1,18 +1,20 @@
 """Provide the SubredditListingMixin class."""
-from ....const import urljoin
+from ....compat import urljoin
+from ...base import PRAWBase
 from ..generator import ListingGenerator
 from .base import BaseListingMixin
 from .gilded import GildedListingMixin
 from .rising import RisingListingMixin
 
 
-class SubredditListingMixin(BaseListingMixin, GildedListingMixin,
-                            RisingListingMixin):
-    """Adds additional methods pertianing to Subreddit-like instances."""
+class SubredditListingMixin(
+    BaseListingMixin, GildedListingMixin, RisingListingMixin
+):
+    """Adds additional methods pertaining to Subreddit-like instances."""
 
     @property
     def comments(self):
-        """An instance of :class:`.CommentHelper`.
+        """Provide an instance of :class:`.CommentHelper`.
 
         For example, to output the author of the 25 most recent comments of
         ``/r/redditdev`` execute:
@@ -33,16 +35,16 @@ class SubredditListingMixin(BaseListingMixin, GildedListingMixin,
         :param reddit: An instance of :class:`.Reddit`.
 
         """
-        super(SubredditListingMixin, self).__init__(reddit, _data)
+        super(SubredditListingMixin, self).__init__(reddit, _data=_data)
         self._comments = None
 
 
-class CommentHelper(GildedListingMixin):
+class CommentHelper(PRAWBase):
     """Provide a set of functions to interact with a subreddit's comments."""
 
     @property
     def _path(self):
-        return urljoin(self.subreddit._path, 'comments/')
+        return urljoin(self.subreddit._path, "comments/")
 
     def __init__(self, subreddit):
         """Initialize a CommentHelper instance."""
@@ -64,3 +66,18 @@ class CommentHelper(GildedListingMixin):
 
         """
         return ListingGenerator(self._reddit, self._path, **generator_kwargs)
+
+    def gilded(self, **generator_kwargs):
+        """Deprecated.
+
+        .. warning:: (Deprecated) This method will be removed in PRAW 6 because
+                     it doesn't actually restrict the results to gilded
+                     Comments. Use ``subreddit.gilded`` instead.
+
+        Additional keyword arguments are passed in the initialization of
+        :class:`.ListingGenerator`.
+
+        """
+        return ListingGenerator(
+            self._reddit, urljoin(self._path, "gilded"), **generator_kwargs
+        )
