@@ -2,35 +2,81 @@
 from ...exceptions import ClientException
 from ..comment_forest import CommentForest
 from .base import RedditBase
-from .mixins import InboxableMixin, ThingModerationMixin, UserContentMixin
+from .mixins import (
+    FullnameMixin,
+    InboxableMixin,
+    ThingModerationMixin,
+    UserContentMixin,
+)
 from .redditor import Redditor
 
 
-class Comment(RedditBase, InboxableMixin, UserContentMixin):
-    """A class that represents a reddit comments."""
+class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
+    """A class that represents a reddit comments.
 
-    MISSING_COMMENT_MESSAGE = ('This comment does not appear to be in the '
-                               'comment tree')
-    STR_FIELD = 'id'
+    **Typical Attributes**
+
+    This table describes attributes that typically belong to objects of this
+    class. Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a
+    guarantee that these attributes will always be present, nor is this list
+    comprehensive in any way.
+
+    ======================= ===================================================
+    Attribute               Description
+    ======================= ===================================================
+    ``author``              Provides an instance of :class:`.Redditor`.
+    ``body``                The body of the comment.
+    ``created_utc``         Time the comment was created, represented in
+                            `Unix Time`_.
+    ``distinguished``       Whether or not the comment is distinguished.
+    ``edited``              Whether or not the comment has been edited.
+    ``id``                  The ID of the comment.
+    ``is_submitter``        Whether or not the comment author is also the
+                            author of the submission.
+    ``link_id``             The submission ID that the comment belongs to.
+    ``parent_id``           The ID of the parent comment. If it is a top-level
+                            comment, this returns the submission ID instead
+                            (prefixed with 't3').
+    ``permalink``           A permalink for the comment.
+    ``replies``             Provides an instance of :class:`.CommentForest`.
+    ``score``               The number of upvotes for the comment.
+    ``stickied``            Whether or not the comment is stickied.
+    ``submission``          Provides an instance of :class:`.Submission`. The
+                            submission that the comment belongs to.
+    ``subreddit``           Provides an instance of :class:`.Subreddit`. The
+                            subreddit that the comment belongs to.
+    ``subreddit_id``        The subreddit ID that the comment belongs to.
+    ======================= ===================================================
+
+
+    .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
+
+    """
+
+    MISSING_COMMENT_MESSAGE = (
+        "This comment does not appear to be in the comment tree"
+    )
+    STR_FIELD = "id"
 
     @staticmethod
     def id_from_url(url):
         """Get the ID of a comment from the full URL."""
         parts = RedditBase._url_parts(url)
         try:
-            comment_index = parts.index('comments')
+            comment_index = parts.index("comments")
         except ValueError:
-            raise ClientException('Invalid URL: {}'.format(url))
+            raise ClientException("Invalid URL: {}".format(url))
 
         if len(parts) - 4 != comment_index:
-            raise ClientException('Invalid URL: {}'.format(url))
+            raise ClientException("Invalid URL: {}".format(url))
         return parts[-1]
 
     @property
     def is_root(self):
         """Return True when the comment is a top level comment."""
-        parent_type = self.parent_id.split('_', 1)[0]
-        return parent_type == self._reddit.config.kinds['submission']
+        parent_type = self.parent_id.split("_", 1)[0]
+        return parent_type == self._reddit.config.kinds["submission"]
 
     @property
     def mod(self):
@@ -46,6 +92,16 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
         This property may return an empty list if the comment
         has not been refreshed with :meth:`.refresh()`
 
+        Sort order and reply limit can be set with the ``reply_sort`` and
+        ``reply_limit`` attributes before replies are fetched, including
+        any call to :meth:`.refresh`:
+
+        .. code:: python
+
+           comment.reply_sort = 'new'
+           comment.refresh()
+           replies = comment.replies
+
         """
         if isinstance(self._replies, list):
             self._replies = CommentForest(self.submission, self._replies)
@@ -56,7 +112,8 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
         """Return the Submission object this comment belongs to."""
         if not self._submission:  # Comment not from submission
             self._submission = self._reddit.submission(
-                self._extract_submission_id())
+                self._extract_submission_id()
+            )
         return self._submission
 
     @submission.setter
@@ -65,17 +122,23 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
         submission._comments_by_id[self.name] = self
         self._submission = submission
         # pylint: disable=not-an-iterable
-        for reply in getattr(self, 'replies', []):
+        for reply in getattr(self, "replies", []):
             reply.submission = submission
 
-    def __init__(self, reddit, id=None,  # pylint: disable=redefined-builtin
-                 url=None, _data=None):
+    def __init__(
+        self,
+        reddit,
+        id=None,  # pylint: disable=redefined-builtin
+        url=None,
+        _data=None,
+    ):
         """Construct an instance of the Comment object."""
         if [id, url, _data].count(None) != 2:
-            raise TypeError('Exactly one of `id`, `url`, or `_data` must be '
-                            'provided.')
+            raise TypeError(
+                "Exactly one of `id`, `url`, or `_data` must be provided."
+            )
         self._mod = self._replies = self._submission = None
-        super(Comment, self).__init__(reddit, _data)
+        super(Comment, self).__init__(reddit, _data=_data)
         if id:
             self.id = id  # pylint: disable=invalid-name
         elif url:
@@ -85,22 +148,22 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
 
     def __setattr__(self, attribute, value):
         """Objectify author, replies, and subreddit."""
-        if attribute == 'author':
+        if attribute == "author":
             value = Redditor.from_data(self._reddit, value)
-        elif attribute == 'replies':
-            if value == '':
+        elif attribute == "replies":
+            if value == "":
                 value = []
             else:
                 value = self._reddit._objector.objectify(value).children
-            attribute = '_replies'
-        elif attribute == 'subreddit':
+            attribute = "_replies"
+        elif attribute == "subreddit":
             value = self._reddit.subreddit(value)
         super(Comment, self).__setattr__(attribute, value)
 
     def _extract_submission_id(self):
-        if 'context' in self.__dict__:
-            return self.context.rsplit('/', 4)[1]
-        return self.link_id.split('_', 1)[1]
+        if "context" in self.__dict__:
+            return self.context.rsplit("/", 4)[1]
+        return self.link_id.split("_", 1)[1]
 
     def parent(self):
         """Return the parent of the comment.
@@ -162,7 +225,7 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
             return self.submission._comments_by_id[self.parent_id]
         # pylint: enable=no-member
 
-        parent = Comment(self._reddit, self.parent_id.split('_', 1)[1])
+        parent = Comment(self._reddit, self.parent_id.split("_", 1)[1])
         parent._submission = self.submission
         return parent
 
@@ -180,16 +243,23 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
            comment.refresh()
 
         """
-        if 'context' in self.__dict__:  # Using hasattr triggers a fetch
-            comment_path = self.context.split('?', 1)[0]
+        if "context" in self.__dict__:  # Using hasattr triggers a fetch
+            comment_path = self.context.split("?", 1)[0]
         else:
-            comment_path = '{}_/{}'.format(
+            comment_path = "{}_/{}".format(
                 self.submission._info_path(),  # pylint: disable=no-member
-                self.id)
+                self.id,
+            )
 
         # The context limit appears to be 8, but let's ask for more anyway.
-        comment_list = self._reddit.get(comment_path,
-                                        params={'context': 100})[1].children
+        params = {"context": 100}
+        if "reply_limit" in self.__dict__:
+            params["limit"] = self.reply_limit
+        if "reply_sort" in self.__dict__:
+            params["sort"] = self.reply_sort
+        comment_list = self._reddit.get(comment_path, params=params)[
+            1
+        ].children
         if not comment_list:
             raise ClientException(self.MISSING_COMMENT_MESSAGE)
 
@@ -205,7 +275,7 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
             raise ClientException(self.MISSING_COMMENT_MESSAGE)
 
         if self._submission is not None:
-            del comment.__dict__['_submission']  # Don't replace if set
+            del comment.__dict__["_submission"]  # Don't replace if set
         self.__dict__.update(comment.__dict__)
 
         for reply in comment_list:
@@ -225,6 +295,8 @@ class CommentModeration(ThingModerationMixin):
 
     """
 
+    REMOVAL_MESSAGE_API = "removal_comment_message"
+
     def __init__(self, comment):
         """Create a CommentModeration instance.
 
