@@ -3,6 +3,7 @@ from ...const import API_PATH
 from ..listing.generator import ListingGenerator
 from ..list.redditor import RedditorList
 from .base import RedditBase
+from .mixins import FullnameMixin
 from .redditor import Redditor
 
 
@@ -12,10 +13,10 @@ class LiveContributorRelationship(object):
     @staticmethod
     def _handle_permissions(permissions):
         if permissions is None:
-            permissions = {'all'}
+            permissions = {"all"}
         else:
             permissions = set(permissions)
-        return ','.join('+{}'.format(x) for x in permissions)
+        return ",".join("+{}".format(x) for x in permissions)
 
     def __call__(self):
         """Return a :class:`.RedditorList` for live threads' contributors.
@@ -29,7 +30,7 @@ class LiveContributorRelationship(object):
                print(contributor)
 
         """
-        url = API_PATH['live_contributors'].format(id=self.thread.id)
+        url = API_PATH["live_contributors"].format(id=self.thread.id)
         temp = self.thread._reddit.get(url)
         return temp if isinstance(temp, RedditorList) else temp[0]
 
@@ -56,7 +57,7 @@ class LiveContributorRelationship(object):
             thread.contributor.accept_invite()
 
         """
-        url = API_PATH['live_accept_invite'].format(id=self.thread.id)
+        url = API_PATH["live_accept_invite"].format(id=self.thread.id)
         self.thread._reddit.post(url)
 
     def invite(self, redditor, permissions=None):
@@ -86,10 +87,12 @@ class LiveContributorRelationship(object):
             remove the invite for redditor.
 
         """
-        url = API_PATH['live_invite'].format(id=self.thread.id)
-        data = {'name': str(redditor),
-                'type': 'liveupdate_contributor_invite',
-                'permissions': self._handle_permissions(permissions)}
+        url = API_PATH["live_invite"].format(id=self.thread.id)
+        data = {
+            "name": str(redditor),
+            "type": "liveupdate_contributor_invite",
+            "permissions": self._handle_permissions(permissions),
+        }
         self.thread._reddit.post(url, data=data)
 
     def leave(self):
@@ -103,7 +106,7 @@ class LiveContributorRelationship(object):
             thread.contributor.leave()
 
         """
-        url = API_PATH['live_leave'].format(id=self.thread.id)
+        url = API_PATH["live_leave"].format(id=self.thread.id)
         self.thread._reddit.post(url)
 
     def remove(self, redditor):
@@ -126,8 +129,8 @@ class LiveContributorRelationship(object):
             fullname = redditor.fullname
         else:
             fullname = redditor
-        data = {'id': fullname}
-        url = API_PATH['live_remove_contrib'].format(id=self.thread.id)
+        data = {"id": fullname}
+        url = API_PATH["live_remove_contrib"].format(id=self.thread.id)
         self.thread._reddit.post(url, data=data)
 
     def remove_invite(self, redditor):
@@ -153,8 +156,8 @@ class LiveContributorRelationship(object):
             fullname = redditor.fullname
         else:
             fullname = redditor
-        data = {'id': fullname}
-        url = API_PATH['live_remove_invite'].format(id=self.thread.id)
+        data = {"id": fullname}
+        url = API_PATH["live_remove_invite"].format(id=self.thread.id)
         self.thread._reddit.post(url, data=data)
 
     def update(self, redditor, permissions=None):
@@ -189,10 +192,12 @@ class LiveContributorRelationship(object):
            subreddit.moderator.update('spez', [])
 
         """
-        url = API_PATH['live_update_perms'].format(id=self.thread.id)
-        data = {'name': str(redditor),
-                'type': 'liveupdate_contributor',
-                'permissions': self._handle_permissions(permissions)}
+        url = API_PATH["live_update_perms"].format(id=self.thread.id)
+        data = {
+            "name": str(redditor),
+            "type": "liveupdate_contributor",
+            "permissions": self._handle_permissions(permissions),
+        }
         self.thread._reddit.post(url, data=data)
 
     def update_invite(self, redditor, permissions=None):
@@ -227,10 +232,12 @@ class LiveContributorRelationship(object):
            thread.contributor.update_invite('spez', [])
 
         """
-        url = API_PATH['live_update_perms'].format(id=self.thread.id)
-        data = {'name': str(redditor),
-                'type': 'liveupdate_contributor_invite',
-                'permissions': self._handle_permissions(permissions)}
+        url = API_PATH["live_update_perms"].format(id=self.thread.id)
+        data = {
+            "name": str(redditor),
+            "type": "liveupdate_contributor_invite",
+            "permissions": self._handle_permissions(permissions),
+        }
         self.thread._reddit.post(url, data=data)
 
 
@@ -260,7 +267,7 @@ class LiveThread(RedditBase):
     .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
     """
 
-    STR_FIELD = 'id'
+    STR_FIELD = "id"
 
     @property
     def contrib(self):
@@ -306,8 +313,7 @@ class LiveThread(RedditBase):
         """
         if isinstance(other, str):
             return other == str(self)
-        return (isinstance(other, self.__class__) and
-                str(self) == str(other))
+        return isinstance(other, self.__class__) and str(self) == str(other)
 
     def __getitem__(self, update_id):
         """Return a lazy :class:`.LiveUpdate` instance.
@@ -331,23 +337,24 @@ class LiveThread(RedditBase):
         """Return the hash of the current instance."""
         return hash(self.__class__.__name__) ^ hash(str(self))
 
-    def __init__(self, reddit, id=None,  # pylint: disable=redefined-builtin
-                 _data=None):
+    def __init__(
+        self, reddit, id=None, _data=None  # pylint: disable=redefined-builtin
+    ):
         """Initialize a lazy :class:`.LiveThread` instance.
 
         :param reddit: An instance of :class:`.Reddit`.
         :param id: A live thread ID, e.g., ``'ukaeu1ik4sw5'``
         """
         if bool(id) == bool(_data):
-            raise TypeError('Either `id` or `_data` must be provided.')
-        super(LiveThread, self).__init__(reddit, _data)
+            raise TypeError("Either `id` or `_data` must be provided.")
+        super(LiveThread, self).__init__(reddit, _data=_data)
         if id:
             self.id = id  # pylint: disable=invalid-name
         self._contrib = None
         self._contributor = None
 
     def _info_path(self):
-        return API_PATH['liveabout'].format(id=self.id)
+        return API_PATH["liveabout"].format(id=self.id)
 
     def discussions(self, **generator_kwargs):
         """Get submissions linking to the thread.
@@ -366,7 +373,7 @@ class LiveThread(RedditBase):
                print(submission.title)
 
         """
-        url = API_PATH['live_discussions'].format(id=self.id)
+        url = API_PATH["live_discussions"].format(id=self.id)
         return ListingGenerator(self._reddit, url, **generator_kwargs)
 
     def report(self, type):  # pylint: disable=redefined-builtin
@@ -384,8 +391,8 @@ class LiveThread(RedditBase):
            thread.report('spam')
 
         """
-        url = API_PATH['live_report'].format(id=self.id)
-        self._reddit.post(url, data={'type': type})
+        url = API_PATH["live_report"].format(id=self.id)
+        self._reddit.post(url, data={"type": type})
 
     def updates(self, **generator_kwargs):
         """Return a :class:`.ListingGenerator` yields :class:`.LiveUpdate` s.
@@ -405,9 +412,8 @@ class LiveThread(RedditBase):
                print(submission.body)
 
         """
-        url = API_PATH['live_updates'].format(id=self.id)
-        for update in ListingGenerator(self._reddit, url,
-                                       **generator_kwargs):
+        url = API_PATH["live_updates"].format(id=self.id)
+        for update in ListingGenerator(self._reddit, url, **generator_kwargs):
             update._thread = self
             yield update
 
@@ -444,8 +450,8 @@ class LiveThreadContribution(object):
            thread.contrib.add('test `LiveThreadContribution.add()`')
 
         """
-        url = API_PATH['live_add_update'].format(id=self.thread.id)
-        self.thread._reddit.post(url, data={'body': body})
+        url = API_PATH["live_add_update"].format(id=self.thread.id)
+        self.thread._reddit.post(url, data={"body": body})
 
     def close(self):
         """Close the live thread permanently (cannot be undone).
@@ -458,11 +464,17 @@ class LiveThreadContribution(object):
            thread.contrib.close()
 
         """
-        url = API_PATH['live_close'].format(id=self.thread.id)
+        url = API_PATH["live_close"].format(id=self.thread.id)
         self.thread._reddit.post(url)
 
-    def update(self, title=None, description=None, nsfw=None, resources=None,
-               **other_settings):
+    def update(
+        self,
+        title=None,
+        description=None,
+        nsfw=None,
+        resources=None,
+        **other_settings
+    ):
         """Update settings of the live thread.
 
         :param title: (Optional) The title of the live thread (default: None).
@@ -498,23 +510,29 @@ class LiveThreadContribution(object):
            thread.contrib.update(nsfw=True, foo=None)
 
         """
-        settings = {'title': title, 'description': description,
-                    'nsfw': nsfw, 'resources': resources}
+        settings = {
+            "title": title,
+            "description": description,
+            "nsfw": nsfw,
+            "resources": resources,
+        }
         settings.update(other_settings)
         if all(value is None for value in settings.values()):
             return
         # get settings from Reddit (not cache)
         thread = LiveThread(self.thread._reddit, self.thread.id)
-        data = {key: getattr(thread, key) if value is None else value
-                for key, value in settings.items()}
+        data = {
+            key: getattr(thread, key) if value is None else value
+            for key, value in settings.items()
+        }
 
-        url = API_PATH['live_update_thread'].format(id=self.thread.id)
+        url = API_PATH["live_update_thread"].format(id=self.thread.id)
         # prawcore (0.7.0) Session.request() modifies `data` kwarg
         self.thread._reddit.post(url, data=data.copy())
         self.thread._reset_attributes(*data.keys())
 
 
-class LiveUpdate(RedditBase):
+class LiveUpdate(FullnameMixin, RedditBase):
     """An individual :class:`.LiveUpdate` object.
 
     **Typical Attributes**
@@ -539,7 +557,7 @@ class LiveUpdate(RedditBase):
     .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
     """
 
-    STR_FIELD = 'id'
+    STR_FIELD = "id"
 
     @property
     def contrib(self):
@@ -588,26 +606,29 @@ class LiveUpdate(RedditBase):
             # Since _data (part of JSON returned from reddit) have no
             # thread ID, self._thread must be set by the caller of
             # LiveUpdate(). See the code of LiveThread.updates() for example.
-            super(LiveUpdate, self).__init__(reddit, _data)
+            super(LiveUpdate, self).__init__(reddit, _data=_data)
             self._fetched = True
         elif thread_id and update_id:
             super(LiveUpdate, self).__init__(reddit, None)
             self._thread = LiveThread(self._reddit, thread_id)
             self.id = update_id  # pylint: disable=invalid-name
         else:
-            raise TypeError('Either `thread_id` and `update_id`, or '
-                            '`_data` must be provided.')
+            raise TypeError(
+                "Either `thread_id` and `update_id`, or "
+                "`_data` must be provided."
+            )
         self._contrib = None
 
     def __setattr__(self, attribute, value):
         """Objectify author."""
-        if attribute == 'author':
+        if attribute == "author":
             value = Redditor(self._reddit, name=value)
         super(LiveUpdate, self).__setattr__(attribute, value)
 
     def _fetch(self):
-        url = API_PATH['live_focus'].format(
-            thread_id=self.thread.id, update_id=self.id)
+        url = API_PATH["live_focus"].format(
+            thread_id=self.thread.id, update_id=self.id
+        )
         other = self._reddit.get(url)[0]
         self.__dict__.update(other.__dict__)
         self._fetched = True
@@ -646,8 +667,8 @@ class LiveUpdateContribution(object):
            update.contrib.remove()
 
         """
-        url = API_PATH['live_remove_update'].format(id=self.update.thread.id)
-        data = {'id': self.update.fullname}
+        url = API_PATH["live_remove_update"].format(id=self.update.thread.id)
+        data = {"id": self.update.fullname}
         self.update.thread._reddit.post(url, data=data)
 
     def strike(self):
@@ -665,6 +686,6 @@ class LiveUpdateContribution(object):
         See :class:`.LiveUpdate` for details.
 
         """
-        url = API_PATH['live_strike'].format(id=self.update.thread.id)
-        data = {'id': self.update.fullname}
+        url = API_PATH["live_strike"].format(id=self.update.thread.id)
+        data = {"id": self.update.fullname}
         self.update.thread._reddit.post(url, data=data)
