@@ -55,7 +55,7 @@ class User(PRAWBase):
 
     def blocked(self):
         """Return a RedditorList of blocked Redditors."""
-        return self._reddit.get(API_PATH['blocked'])
+        return self._reddit.get(API_PATH["blocked"])
 
     def contributor_subreddits(self, **generator_kwargs):
         """Return a ListingGenerator of subreddits user is a contributor of.
@@ -64,25 +64,28 @@ class User(PRAWBase):
         :class:`.ListingGenerator`.
 
         """
-        return ListingGenerator(self._reddit, API_PATH['my_contributor'],
-                                **generator_kwargs)
+        return ListingGenerator(
+            self._reddit, API_PATH["my_contributor"], **generator_kwargs
+        )
 
     def friends(self):
         """Return a RedditorList of friends."""
-        return self._reddit.get(API_PATH['friends'])
+        return self._reddit.get(API_PATH["friends"])
 
     def karma(self):
         """Return a dictionary mapping subreddits to their karma."""
         karma_map = {}
-        for row in self._reddit.get(API_PATH['karma'])['data']:
-            subreddit = Subreddit(self._reddit, row['sr'])
-            del row['sr']
+        for row in self._reddit.get(API_PATH["karma"])["data"]:
+            subreddit = Subreddit(self._reddit, row["sr"])
+            del row["sr"]
             karma_map[subreddit] = row
         return karma_map
 
     def me(self, use_cache=True):  # pylint: disable=invalid-name
         """Return a :class:`.Redditor` instance for the authenticated user.
 
+        In :attr:`~praw.Reddit.read_only` mode, this method returns ``None``.
+
         :param use_cache: When true, and if this function has been previously
             called, returned the cached version (default: True).
 
@@ -91,8 +94,10 @@ class User(PRAWBase):
            instances, however, for distinct authorizations.
 
         """
+        if self._reddit.read_only:
+            return None
         if self._me is None or not use_cache:
-            user_data = self._reddit.get(API_PATH['me'])
+            user_data = self._reddit.get(API_PATH["me"])
             self._me = Redditor(self._reddit, _data=user_data)
         return self._me
 
@@ -103,12 +108,13 @@ class User(PRAWBase):
         :class:`.ListingGenerator`.
 
         """
-        return ListingGenerator(self._reddit, API_PATH['my_moderator'],
-                                **generator_kwargs)
+        return ListingGenerator(
+            self._reddit, API_PATH["my_moderator"], **generator_kwargs
+        )
 
     def multireddits(self):
         """Return a list of multireddits belonging to the user."""
-        return self._reddit.get(API_PATH['my_multireddits'])
+        return self._reddit.get(API_PATH["my_multireddits"])
 
     def subreddits(self, **generator_kwargs):
         """Return a ListingGenerator of subreddits the user is subscribed to.
@@ -117,5 +123,6 @@ class User(PRAWBase):
         :class:`.ListingGenerator`.
 
         """
-        return ListingGenerator(self._reddit, API_PATH['my_subreddits'],
-                                **generator_kwargs)
+        return ListingGenerator(
+            self._reddit, API_PATH["my_subreddits"], **generator_kwargs
+        )
